@@ -112,6 +112,7 @@ static char *s_chtml20_start_blink_tag   (void *pdoc, Node *node);
 static char *s_chtml20_end_blink_tag     (void *pdoc, Node *node);
 static char *s_chtml20_start_marquee_tag   (void *pdoc, Node *node);
 static char *s_chtml20_end_marquee_tag     (void *pdoc, Node *node);
+static char *s_chtml20_newline_mark       (void *pdoc, Node *node);
 
 static void  s_init_chtml20(chtml20_t *chtml, Doc *doc, request_rec *r, device_table *spec);
 
@@ -387,6 +388,11 @@ tag_handler chtml20_handler[] = {
     s_chtml20_start_marquee_tag,
     s_chtml20_end_marquee_tag,
   },
+  /* tagNLMARK */
+  {
+    s_chtml20_newline_mark,
+    NULL,
+  },
 };
 
 /**
@@ -584,7 +590,6 @@ s_chtml20_start_html_tag(void *pdoc, Node *UNUSED(node))
   /* start HTML tag                                                           */
   /*--------------------------------------------------------------------------*/
   W_L("<html>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -609,7 +614,6 @@ s_chtml20_end_html_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</html>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -711,7 +715,6 @@ s_chtml20_start_meta_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -752,7 +755,6 @@ s_chtml20_start_head_tag(void *pdoc, Node *UNUSED(node))
   doc     = chtml20->doc;
 
   W_L("<head>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -778,7 +780,6 @@ s_chtml20_end_head_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</head>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -804,7 +805,6 @@ s_chtml20_start_title_tag(void *pdoc, Node *UNUSED(node))
   r       = doc->r;
 
   W_L("<title>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -830,7 +830,6 @@ s_chtml20_end_title_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</title>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -872,7 +871,6 @@ s_chtml20_start_base_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -992,7 +990,6 @@ s_chtml20_start_body_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1018,7 +1015,6 @@ s_chtml20_end_body_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</body>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1211,7 +1207,6 @@ s_chtml20_end_a_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</a>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1255,7 +1250,6 @@ s_chtml20_start_br_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1327,7 +1321,6 @@ s_chtml20_end_tr_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("<br>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1494,7 +1487,6 @@ s_chtml20_start_form_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1520,7 +1512,6 @@ s_chtml20_end_form_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</form>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1593,7 +1584,7 @@ s_chtml20_start_input_tag(void *pdoc, Node *node)
   }
   if (value && *value) {
     W_L(" value=\"");
-    W_V(value);
+    W_V(chxj_add_slash_to_doublequote(doc->pool, value));
     W_L("\"");
   }
   if (accesskey && *accesskey) {
@@ -1631,7 +1622,6 @@ s_chtml20_start_input_tag(void *pdoc, Node *node)
     W_L(" checked");
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1704,7 +1694,6 @@ s_chtml20_end_center_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</center>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1730,7 +1719,6 @@ s_chtml20_start_ul_tag(void *pdoc, Node *UNUSED(node))
   r       = doc->r;
 
   W_L("<ul>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1756,7 +1744,6 @@ s_chtml20_end_ul_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</ul>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1803,7 +1790,6 @@ s_chtml20_start_ol_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1829,7 +1815,6 @@ s_chtml20_end_ol_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</ol>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -1991,7 +1976,6 @@ s_chtml20_start_hr_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2168,7 +2152,6 @@ s_chtml20_start_img_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2269,7 +2252,6 @@ s_chtml20_start_select_tag(void *pdoc, Node *child)
     W_L(" multiple");
   }
   W_L(">");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2292,7 +2274,6 @@ s_chtml20_end_select_tag(void *pdoc, Node *UNUSED(child))
   doc     = chtml20->doc;
 
   W_L("</select>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2448,7 +2429,6 @@ s_chtml20_end_div_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</div>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2511,7 +2491,6 @@ s_chtml20_end_h1_tag(void *pdoc, Node *UNUSED(child))
   doc     = chtml20->doc;
 
   W_L("</h1>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2571,7 +2550,6 @@ s_chtml20_end_h2_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</h2>");
-  W_NLCODE();
 
   return chtml20->out;
 }
@@ -2632,7 +2610,6 @@ s_chtml20_end_h3_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</h3>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2692,7 +2669,6 @@ s_chtml20_end_h4_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</h4>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2752,7 +2728,6 @@ s_chtml20_end_h5_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</h5>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2812,7 +2787,6 @@ s_chtml20_end_h6_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</h6>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2833,7 +2807,6 @@ s_chtml20_start_pre_tag(void *pdoc, Node *UNUSED(node))
 
   chtml20->pre_flag++;
   W_L("<pre>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2853,7 +2826,6 @@ s_chtml20_end_pre_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</pre>");
-  W_NLCODE();
   chtml20->pre_flag--;
 
   return chtml20->out;
@@ -2903,7 +2875,6 @@ s_chtml20_start_p_tag(void *pdoc, Node *node)
     W_L("\"");
   }
   W_L(">");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -2928,7 +2899,6 @@ s_chtml20_end_p_tag(void *pdoc, Node *UNUSED(child))
   r       = doc->r;
 
   W_L("</p>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3035,7 +3005,6 @@ s_chtml20_start_textarea_tag(void *pdoc, Node *node)
     }
   }
   W_L(">");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3055,7 +3024,6 @@ s_chtml20_end_textarea_tag(void *pdoc, Node *UNUSED(child))
   Doc         *doc     = chtml20->doc;
 
   W_L("</textarea>");
-  W_NLCODE();
   chtml20->textarea_flag--;
 
   return chtml20->out;
@@ -3141,7 +3109,6 @@ s_chtml20_start_blockquote_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc     = chtml20->doc;
   W_L("<blockquote>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3160,7 +3127,6 @@ s_chtml20_end_blockquote_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc     = chtml20->doc;
   W_L("</blockquote>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3179,7 +3145,6 @@ s_chtml20_start_dir_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc     = chtml20->doc;
   W_L("<dir>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3199,7 +3164,6 @@ s_chtml20_end_dir_tag(void *pdoc, Node *UNUSED(child))
   Doc       *doc     = chtml20->doc;
 
   W_L("</dir>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3218,7 +3182,6 @@ s_chtml20_start_dl_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc     = chtml20->doc;
   W_L("<dl>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3237,7 +3200,6 @@ s_chtml20_end_dl_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc     = chtml20->doc;
   W_L("</dl>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3327,7 +3289,6 @@ s_chtml20_start_menu_tag(void *pdoc, Node *UNUSED(child))
   Doc       *doc     = chtml20->doc;
 
   W_L("<menu>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3347,7 +3308,6 @@ s_chtml20_end_menu_tag(void *pdoc, Node *UNUSED(child))
   Doc       *doc = chtml20->doc;
 
   W_L("</menu>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3435,7 +3395,6 @@ s_chtml20_end_blink_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc = chtml20->doc;
   W_L("</blink>");
-  W_NLCODE();
   return chtml20->out;
 }
 
@@ -3504,6 +3463,18 @@ s_chtml20_end_marquee_tag(void *pdoc, Node *UNUSED(child))
   chtml20_t *chtml20 = GET_CHTML20(pdoc);
   Doc       *doc = chtml20->doc;
   W_L("</marquee>");
+  return chtml20->out;
+}
+
+
+/**
+ *  * It is handler who processes the New Line Code.
+ *   */
+static char *
+s_chtml20_newline_mark(void *pdoc, Node *UNUSED(node))
+{
+  chtml20_t *chtml20 = GET_CHTML20(pdoc);
+  Doc *doc = chtml20->doc;
   W_NLCODE();
   return chtml20->out;
 }
