@@ -40,12 +40,12 @@ chxj_save_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id,
   apr_dbm_t           *f;
   apr_file_t          *file;
 
-  DBG(r, "REQ[%X] start chxj_save_cookie_dbm() cookie_id:[%s] store_string:[%s]", (unsigned int)(apr_size_t)r, cookie_id, store_string);
+  DBG(r, "start chxj_save_cookie_dbm() cookie_id:[%s]", cookie_id);
 
   file = chxj_cookie_db_lock(r);
   if (! file) {
     ERR(r, "mod_chxj: Can't lock cookie db");
-    DBG(r, "REQ[%X] end chxj_save_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+    DBG(r, "end chxj_save_cookie_dbm() cookie_id:[%s]", cookie_id);
     return CHXJ_FALSE;
   }
 
@@ -60,7 +60,7 @@ chxj_save_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id,
             "default",
             chxj_cookie_db_name_create(r,m->cookie_db_dir));
     chxj_cookie_db_unlock(r, file);
-    DBG(r, "REQ[%X] end chxj_save_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+    DBG(r, "end chxj_save_cookie_dbm() cookie_id:[%s]", cookie_id);
     return CHXJ_FALSE;
   }
 
@@ -83,13 +83,13 @@ chxj_save_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id,
             chxj_cookie_db_name_create(r, m->cookie_db_dir));
     apr_dbm_close(f);
     chxj_cookie_db_unlock(r, file);
-    DBG(r, "REQ[%X] end chxj_save_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+    DBG(r, "end chxj_save_cookie_dbm() cookie_id:[%s]", cookie_id);
     return CHXJ_FALSE;
   }
 
   apr_dbm_close(f);
   chxj_cookie_db_unlock(r, file);
-  DBG(r, "REQ[%X] end chxj_save_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+  DBG(r, "end chxj_save_cookie_dbm() cookie_id:[%s]", cookie_id);
   return CHXJ_TRUE;
 }
 
@@ -355,11 +355,11 @@ chxj_load_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id)
   apr_datum_t             dbmval;
   apr_datum_t             dbmkey;
 
-  DBG(r, "REQ[%X] start chxj_load_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+  DBG(r, "start chxj_load_cookie_dbm() cookie_id:[%s]", cookie_id);
   file = chxj_cookie_db_lock(r);
   if (! file) {
     ERR(r, "mod_chxj: Can't lock cookie db");
-    DBG(r, "REQ[%X] end   chxj_load_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+    DBG(r, "end   chxj_load_cookie_dbm() cookie_id:[%s]", cookie_id);
     return NULL;
   }
 
@@ -371,13 +371,11 @@ chxj_load_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id)
                            r->pool);
   if (retval != APR_SUCCESS) {
     ERR(r,
-         "%s:%d"
          "could not open dbm (type %s) auth file: %s",
-         __FILE__,__LINE__,
          "default",
          chxj_cookie_db_name_create(r, m->cookie_db_dir));
     chxj_cookie_db_unlock(r, file);
-    DBG(r, "REQ[%X] end   chxj_load_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+    DBG(r, "end   chxj_load_cookie_dbm() cookie_id:[%s]", cookie_id);
     return NULL;
   }
 
@@ -391,14 +389,11 @@ chxj_load_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id)
     retval = apr_dbm_fetch(f, dbmkey, &dbmval);
     if (retval != APR_SUCCESS) {
       ERR(r,
-           "%s:%d"
-           "could not fetch dbm (type %s) auth file: %s",
-           __FILE__,__LINE__,
-           "default",
+           "could not fetch dbm (type %s) auth file: %s", "default",
            chxj_cookie_db_name_create(r, m->cookie_db_dir));
       apr_dbm_close(f);
       chxj_cookie_db_unlock(r, file);
-      DBG(r, "REQ[%X] end   chxj_load_cookie_dbm() cookie_id:[%s]", (unsigned int)(apr_size_t)r, cookie_id);
+      DBG(r, "end   chxj_load_cookie_dbm() cookie_id:[%s]", cookie_id);
       return NULL;
     }
     load_string = apr_palloc(r->pool, dbmval.dsize+1);
@@ -408,7 +403,7 @@ chxj_load_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id)
   }
   apr_dbm_close(f);
   chxj_cookie_db_unlock(r, file);
-  DBG(r, "REQ[%X] end   chxj_load_cookie_dbm() cookie_id:[%s] load_string:[%s]", (unsigned int)(apr_size_t)r, cookie_id, load_string);
+  DBG(r, "end   chxj_load_cookie_dbm() cookie_id:[%s]", cookie_id);
   return load_string;
 }
 
@@ -419,7 +414,7 @@ chxj_delete_cookie_dbm(request_rec *r, mod_chxj_config *m, const char *cookie_id
   apr_status_t      retval;
   apr_file_t        *file;
   apr_datum_t       dbmkey;
-  apr_dbm_t*        f;
+  apr_dbm_t         *f;
 
   DBG(r, "start chxj_delete_cookie_dbm() cookie_id:[%s]", cookie_id);
   file = chxj_cookie_db_lock(r);
@@ -468,7 +463,7 @@ chxj_save_cookie_expire_dbm(request_rec *r, mod_chxj_config *m, const char *cook
   apr_file_t              *file;
   apr_datum_t             dbmkey;
   apr_datum_t             dbmval;
-  apr_dbm_t*              f;
+  apr_dbm_t               *f;
 
   DBG(r, "start chxj_save_cookie_expire_dbm() cookie_id:[%s]", cookie_id);
   file = chxj_cookie_expire_db_lock(r);
@@ -478,8 +473,6 @@ chxj_save_cookie_expire_dbm(request_rec *r, mod_chxj_config *m, const char *cook
     return CHXJ_FALSE;
   }
 
-  DBG(r, " ");
-
   retval = apr_dbm_open_ex(&f, 
                            "default", 
                            chxj_cookie_expire_db_name_create(r, m->cookie_db_dir), 
@@ -536,8 +529,8 @@ chxj_delete_cookie_expire_dbm(request_rec *r, mod_chxj_config *m, const char *co
 {
   apr_status_t      retval;
   apr_datum_t       dbmkey;
-  apr_dbm_t*        f;
-  apr_file_t*       file;
+  apr_dbm_t         *f;
+  apr_file_t        *file;
 
   DBG(r, "start chxj_delete_cookie_expire_dbm() cookie_id:[%s]", cookie_id);
   file = chxj_cookie_expire_db_lock(r);
@@ -584,8 +577,8 @@ chxj_cookie_expire_gc_dbm(request_rec *r, mod_chxj_config *m)
   apr_status_t      retval;
   apr_datum_t       dbmkey;
   apr_datum_t       dbmval;
-  apr_dbm_t*        f;
-  apr_file_t*       file;
+  apr_dbm_t         *f;
+  apr_file_t        *file;
   time_t            now_time;
 
   DBG(r, "start chxj_cookie_expire_gc_dbm()");
@@ -669,19 +662,16 @@ chxj_cookie_expire_gc_dbm(request_rec *r, mod_chxj_config *m)
 }
 
 
-cookie_lock_t *
-chxj_cookie_lock_dbm(request_rec *r, mod_chxj_config *UNUSED(m))
+int
+chxj_cookie_lock_dbm(request_rec *UNUSED(r), mod_chxj_config *UNUSED(m))
 {
-  cookie_lock_t *ret = apr_palloc(r->pool, sizeof(*ret));
-  ret->file = chxj_cookie_db_lock(r);
-  return ret;
+  return 1;  /* allways true */
 }
 
 
 int
-chxj_cookie_unlock_dbm(request_rec *r, cookie_lock_t *lock, mod_chxj_config *UNUSED(m))
+chxj_cookie_unlock_dbm(request_rec *UNUSED(r), mod_chxj_config *UNUSED(m))
 {
-  chxj_cookie_expire_db_unlock(r, lock->file);
   return 1; /* allways true */
 }
 /*
